==> apigateway-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/BasePathMappingProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:22:40.378Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BasePathMappingProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.apigateway.BasePathMappingOptions {
    /**
     * The DomainName to associate with this base path mapping.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.apigateway.IDomainName getDomainName();

    /**
     * The RestApi resource to target.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.apigateway.IRestApi getRestApi();

    /**
     * @return a {@link Builder} of {@link BasePathMappingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link BasePathMappingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private software.amazon.awscdk.services.apigateway.IDomainName domainName;
        private software.amazon.awscdk.services.apigateway.IRestApi restApi;
        private java.lang.String basePath;

        /**
         * Sets the value of DomainName
         * @param domainName The DomainName to associate with this base path mapping.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domainName(software.amazon.awscdk.services.apigateway.IDomainName domainName) {
            this.domainName = domainName;
            return this;
        }

        /**
         * Sets the value of RestApi
         * @param restApi The RestApi resource to target.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder restApi(software.amazon.awscdk.services.apigateway.IRestApi restApi) {
            this.restApi = restApi;
            return this;
        }

        /**
         * Sets the value of BasePath
         * @param basePath The base path name that callers of the API must provide in the URL after the domain name (e.g. `example.com/base-path`). If you specify this property, it can't be an empty string.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder basePath(java.lang.String basePath) {
            this.basePath = basePath;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BasePathMappingProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public BasePathMappingProps build() {
            return new Jsii$Proxy(domainName, restApi, basePath);
        }

    }

    /**
     * An implementation for {@link BasePathMappingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BasePathMappingProps {
        private final software.amazon.awscdk.services.apigateway.IDomainName domainName;
        private final software.amazon.awscdk.services.apigateway.IRestApi restApi;
        private final java.lang.String basePath;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.domainName = this.jsiiGet("domainName", software.amazon.awscdk.services.apigateway.IDomainName.class);
            this.restApi = this.jsiiGet("restApi", software.amazon.awscdk.services.apigateway.IRestApi.class);
            this.basePath = this.jsiiGet("basePath", java.lang.String.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(software.amazon.awscdk.services.apigateway.IDomainName domainName, software.amazon.awscdk.services.apigateway.IRestApi restApi, java.lang.String basePath) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainName = java.util.Objects.requireNonNull(domainName, "domainName is required");
            this.restApi = java.util.Objects.requireNonNull(restApi, "restApi is required");
            this.basePath = basePath;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.IDomainName getDomainName() {
            return this.domainName;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.IRestApi getRestApi() {
            return this.restApi;
        }

        @Override
        public java.lang.String getBasePath() {
            return this.basePath;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("domainName", om.valueToTree(this.getDomainName()));
            obj.set("restApi", om.valueToTree(this.getRestApi()));
            if (this.getBasePath() != null) {
                obj.set("basePath", om.valueToTree(this.getBasePath()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BasePathMappingProps.Jsii$Proxy that = (BasePathMappingProps.Jsii$Proxy) o;

            if (!domainName.equals(that.domainName)) return false;
            if (!restApi.equals(that.restApi)) return false;
            return this.basePath != null ? this.basePath.equals(that.basePath) : that.basePath == null;
        }

        @Override
        public int hashCode() {
            int result = this.domainName.hashCode();
            result = 31 * result + (this.restApi.hashCode());
            result = 31 * result + (this.basePath != null ? this.basePath.hashCode() : 0);
            return result;
        }

    }
}

==> apigateway-1.10.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/BasePathMappingProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-30T08:39:26.047Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BasePathMappingProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.apigateway.BasePathMappingOptions {

    /**
     * The DomainName to associate with this base path mapping.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.apigateway.IDomainName getDomainName();

    /**
     * The RestApi resource to target.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.apigateway.IRestApi getRestApi();

    /**
     * @return a {@link Builder} of {@link BasePathMappingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BasePathMappingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private software.amazon.awscdk.services.apigateway.IDomainName domainName;
        private software.amazon.awscdk.services.apigateway.IRestApi restApi;
        private java.lang.String basePath;

        /**
         * Sets the value of DomainName
         * @param domainName The DomainName to associate with this base path mapping. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domainName(software.amazon.awscdk.services.apigateway.IDomainName domainName) {
            this.domainName = domainName;
            return this;
        }

        /**
         * Sets the value of RestApi
         * @param restApi The RestApi resource to target. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder restApi(software.amazon.awscdk.services.apigateway.IRestApi restApi) {
            this.restApi = restApi;
            return this;
        }

        /**
         * Sets the value of BasePath
         * @param basePath The base path name that callers of the API must provide in the URL after the domain name (e.g. `example.com/base-path`). If you specify this property, it can't be an empty string.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder basePath(java.lang.String basePath) {
            this.basePath = basePath;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BasePathMappingProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public BasePathMappingProps build() {
            return new Jsii$Proxy(domainName, restApi, basePath);
        }
    }

    /**
     * An implementation for {@link BasePathMappingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BasePathMappingProps {
        private final software.amazon.awscdk.services.apigateway.IDomainName domainName;
        private final software.amazon.awscdk.services.apigateway.IRestApi restApi;
        private final java.lang.String basePath;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.domainName = this.jsiiGet("domainName", software.amazon.awscdk.services.apigateway.IDomainName.class);
            this.restApi = this.jsiiGet("restApi", software.amazon.awscdk.services.apigateway.IRestApi.class);
            this.basePath = this.jsiiGet("basePath", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(software.amazon.awscdk.services.apigateway.IDomainName domainName, software.amazon.awscdk.services.apigateway.IRestApi restApi, java.lang.String basePath) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainName = java.util.Objects.requireNonNull(domainName, "domainName is required");
            this.restApi = java.util.Objects.requireNonNull(restApi, "restApi is required");
            this.basePath = basePath;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.IDomainName getDomainName() {
            return this.domainName;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.IRestApi getRestApi() {
            return this.restApi;
        }

        @Override
        public java.lang.String getBasePath() {
            return this.basePath;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("domainName", om.valueToTree(this.getDomainName()));
            obj.set("restApi", om.valueToTree(this.getRestApi()));
            if (this.getBasePath() != null) {
                obj.set("basePath", om.valueToTree(this.getBasePath()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BasePathMappingProps.Jsii$Proxy that = (BasePathMappingProps.Jsii$Proxy) o;

            if (!domainName.equals(that.domainName)) return false;
            if (!restApi.equals(that.restApi)) return false;
            return this.basePath != null ? this.basePath.equals(that.basePath) : that.basePath == null;
        }

        @Override
        public int hashCode() {
            int result = this.domainName.hashCode();
            result = 31 * result + (this.restApi.hashCode());
            result = 31 * result + (this.basePath != null ? this.basePath.hashCode() : 0);
            return result;
        }
    }
}
